"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/handler.ts
var handler_exports = {};
__export(handler_exports, {
  handleHtml: () => handleHtml
});
module.exports = __toCommonJS(handler_exports);
var import_stream = require("stream");

// src/utils.ts
function isHtml(value) {
  if (typeof value !== "string")
    return false;
  value = value.trim();
  const length = value.length;
  return (
    // Minimum html is 7 characters long: <a></a>
    length >= 7 && // open tag
    value[0] === "<" && // close tag
    value[length - 1] === ">"
  );
}
function isTagHtml(value) {
  return value.trimStart().slice(0, 5).startsWith("<html");
}

// src/handler.ts
function handleHtml(value, options, hasContentType) {
  if (value instanceof Promise) {
    return value.then((v) => handleHtml(v, options, hasContentType));
  }
  if (typeof value === "string") {
    if (options.autoDoctype && isHtml(value) && // Avoids double adding !doctype or adding to non root html tags.
    isTagHtml(value))
      value = "<!doctype html>" + value;
    return new Response(
      value,
      hasContentType ? void 0 : { headers: { "content-type": options.contentType } }
    );
  }
  let stream = import_stream.Readable.toWeb(value);
  if (options.autoDoctype) {
    let first = true;
    stream = stream.pipeThrough(
      new TransformStream({
        transform(chunk, controller) {
          let str = chunk.toString();
          if (first && isTagHtml(str) && // Avoids double adding !doctype or adding to non root html tags.
          isTagHtml(str)) {
            first = false;
            str = "<!doctype html>" + str;
          }
          controller.enqueue(str);
        }
      })
    );
  }
  return new Response(
    stream,
    hasContentType ? void 0 : { headers: { "content-type": options.contentType } }
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handleHtml
});
